@@ -3,9 +3,9 @@ import { Platform } from 'react-native'
 const cheerio = require('react-native-cheerio')
 
 import {NativeModules} from 'react-native';
-module.exports = NativeModules.ToastExample;
+// module.exports = NativeModules.ToastExample;
 
-import ToastExample from './ToastExample';
+// import ToastExample from './ToastExample';
 
 
 
@@ -31,7 +31,7 @@ var DemoLibrary = {
 
       }).then(response => response.text())
         .then((response) => {
-          ToastExample.show('Awesome', ToastExample.SHORT);
+          NativeModules.ToastExample.show('Awesome', NativeModules.ToastExample.SHORT);
           const $ = cheerio.load(response)
           var version = $('<div/>').html(response).contents().find('div[itemprop=\"softwareVersion\"]').text().trim()
           console.log('version ', version)
